==> jammo_0.6.4.tar.gz: jammo-0.6.4/tests/chum/test-game.c <==
#include <meam/jammo-meam.h>
#include <chum/jammo-chum.h>
#include <chum/jammo-sample-button.h>
#include <chum/jammo-game.h>
#include <glib.h>

#define FILENAME "test-game.json"

void on_sample_button_listened(JammoGame* game, JammoSampleButton* sample_button) {
	jammo_game_set_task_completed(game, clutter_get_script_id(G_OBJECT(sample_button)), TRUE);
}

void on_game_started(JammoGame* game) {
	g_print("MENTOR: Try to play three different loops.\n");
}

void on_task_completed(JammoGame* game, const gchar* task_name, guint tasks_completed) {
	gint tasks_left;
	
	tasks_left = (gint)jammo_game_get_tasks_to_complete(game) - (gint)tasks_completed;
	if (tasks_left > 0) {
		g_print("MENTOR: Good! Listen %u more loops.\n", tasks_left);
	}
}

void on_task_redone(JammoGame* game, const gchar* task_name, guint tasks_completed) {
	g_print("MENTOR: You had already listened this loop. Try another!\n");
}

void on_game_completed(JammoGame* game) {
	g_print("MENTOR: Excellent! Now you have accomplished the whole game. Please, proceed.\n");
}

int main(int argc, char** argv) {
	ClutterActor* stage;
	GError* error = NULL;
	ClutterScript* script;
	ClutterActor* actor;
	
	jammo_meam_init(&argc, &argv);
	jammo_chum_init(&argc, &argv);
	
	stage = clutter_stage_get_default();
	g_object_set(G_OBJECT(stage), "width", 800.0, "height", 480.0, NULL);

	g_print("%ld %ld %p\n", JAMMO_TYPE_SAMPLE_BUTTON, JAMMO_TYPE_GAME, on_sample_button_listened);
	
	script = clutter_script_new();
	if (!clutter_script_load_from_file(script, FILENAME, &error)) {
		g_critical("Error when loading '%s': %s", FILENAME, error->message);
	} else if (!(actor = CLUTTER_ACTOR(clutter_script_get_object(script, "main")))) {
		g_critical("Could not find an object named 'main' from '%s'.", FILENAME);
	} else {
		clutter_container_add_actor(CLUTTER_CONTAINER(stage), actor);
	}

	clutter_actor_show_all(stage);
	
	jammo_game_start(JAMMO_GAME(clutter_script_get_object(script, "the-game")));
	
	clutter_main();
	
	return 0;
}

==> jammo_0.6.13.tar.gz: jammo-0.6.13/tests/chum/test-game.c <==
#include <meam/jammo-meam.h>
#include <chum/jammo-chum.h>
#include <chum/jammo-sample-button.h>
#include <chum/jammo-game.h>
#include <glib.h>

#define FILENAME "test-game.json"

void on_sample_button_listened(JammoGame* game, JammoSampleButton* sample_button) {
	jammo_game_set_task_completed(game, clutter_get_script_id(G_OBJECT(sample_button)), TRUE);
}

void on_game_started(JammoGame* game) {
	g_print("MENTOR: Try to play three different loops.\n");
}

void on_task_completed(JammoGame* game, const gchar* task_name, guint tasks_completed) {
	gint tasks_left;
	
	tasks_left = (gint)jammo_game_get_tasks_to_complete(game) - (gint)tasks_completed;
	if (tasks_left > 0) {
		g_print("MENTOR: Good! Listen %u more loops.\n", tasks_left);
	}
}

void on_task_redone(JammoGame* game, const gchar* task_name, guint tasks_completed) {
	g_print("MENTOR: You had already listened this loop. Try another!\n");
}

void on_game_completed(JammoGame* game) {
	g_print("MENTOR: Excellent! Now you have accomplished the whole game. Please, proceed.\n");
}

int main(int argc, char** argv) {
	ClutterActor* stage;
	GError* error = NULL;
	ClutterScript* script;
	ClutterActor* actor;
	
	jammo_meam_init(&argc, &argv, "jammo_test_duration_cache");
	jammo_chum_init(&argc, &argv);
	
	stage = clutter_stage_get_default();
	g_object_set(G_OBJECT(stage), "width", 800.0, "height", 480.0, NULL);

	g_print("%ld %ld %p\n", JAMMO_TYPE_SAMPLE_BUTTON, JAMMO_TYPE_GAME, on_sample_button_listened);
	
	script = clutter_script_new();
	if (!clutter_script_load_from_file(script, FILENAME, &error)) {
		g_critical("Error when loading '%s': %s", FILENAME, error->message);
	} else if (!(actor = CLUTTER_ACTOR(clutter_script_get_object(script, "main")))) {
		g_critical("Could not find an object named 'main' from '%s'.", FILENAME);
	} else {
		clutter_container_add_actor(CLUTTER_CONTAINER(stage), actor);
	}

	clutter_actor_show_all(stage);
	
	jammo_game_start(JAMMO_GAME(clutter_script_get_object(script, "the-game")));
	
	clutter_main();
	
	return 0;
}
